@@ -3,6 +3,8 @@
 package KiokuDB::Entry;
 use Moose;
 
+use Storable ();
+
 use Moose::Util::TypeConstraints;
 
 use namespace::clean -except => 'meta';
@@ -266,6 +268,11 @@ sub STORABLE_thaw {
     }
 }
 
+sub clone {
+    my $self = shift;
+    Storable::dclone($self); # FIXME a little excessive perhaps?
+}
+
 __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
